AIOBoot - Python asynchronous application framework, built on top of famous libraries.
======================================================================================

[![Build Status](https://travis-ci.com/antonrh/aioboot.svg?branch=master)](https://travis-ci.com/antonrh/aioboot.svg?branch=master)
[![Code coverage](https://codecov.io/gh/antonrh/aioboot/branch/master/graph/badge.svg)](https://codecov.io/gh/antonrh/aioboot)
[![Documentation Status](https://readthedocs.org/projects/aioboot/badge/?version=latest)](https://aioboot.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

---

**Documentation:** https://aioboot.readthedocs.io/en/latest/
